﻿using System;
using System.Collections.Generic;
using System.IO;
using System.Threading;
using System.Windows.Forms;

using WoTPinger.Core;
using WoTPinger.Core.Configuration;
using WoTPinger.Properties;
using WoTPinger.UserInterface;
using WoTPinger.UserInterface.Controls;
using WoTPinger.UserInterface.Forms;

namespace WoTPinger
{
	internal static class Program
	{
		private const string ConfigFileName = "Config.xml";
		private const string ErrorLogFileName = "Errors.log";

		[STAThread]
		public static void Main()
		{
			Application.EnableVisualStyles();
			Application.SetCompatibleTextRenderingDefault(false);

			Application.ThreadException += HandleMainThreadException;

			IConfiguration config = LoadConfiguration(ConfigFileName);
			IList<WPPingControl> pingControls = CreatePingControls(config);

			using (var mainForm = new MainForm(pingControls))
				SingleApplication.Run(mainForm);
		}

		private static void HandleMainThreadException(object sender, ThreadExceptionEventArgs e)
		{
			File.AppendAllText(ErrorLogFileName,
				String.Format("{0:dd-MM-yyyy HH:mm} | {1}\r\n\r\n", DateTime.Now, e.Exception));

			WindowHelper.Error(Resources.ApplicationError);
			Application.Exit();
		}

		private static IConfiguration LoadConfiguration(string fileName)
		{
			if (!File.Exists(fileName))
				File.WriteAllText(fileName, Resources.Config);

			return new XmlConfiguration(fileName);
		}

		private static IList<WPPingControl> CreatePingControls(IConfiguration configuration)
		{
			IList<Server> servers = configuration.GetServers();
			IList<WPPingControl> pingControls = new List<WPPingControl>();

			if (servers.Count == 0)
			{
				WindowHelper.Warning(Resources.ServersAreEmpty);
			}
			else
			{
				int goodPing = configuration.GoodPing;
				int badPing = configuration.BadPing;
				int interval = configuration.PingInterval;

				foreach (var server in servers)
				{
					pingControls.Add(new WPPingControl(server, goodPing, badPing, interval));
				}
			}

			return pingControls;
		}
	}
}