﻿using System;
using System.Windows.Forms;

using WoTPinger.Properties;
using WoTPinger.UserInterface.Controls;

namespace WoTPinger.UserInterface.Forms
{
	public sealed partial class HelpForm : WPForm
	{
		private const int TopBorderHeight = 40;

		public HelpForm()
		{
			InitializeComponent();
			Text = Resources.HelpFormName;

			AddHelpPage(HelpPageBuilder.BuildServersPage());
			AddHelpPage(HelpPageBuilder.BuildPingParametersPage());
			AddHelpPage(HelpPageBuilder.BuildAuthorsPage());

			ttHelp.SetToolTip(btnServers, Resources.ServersTip);
			ttHelp.SetToolTip(btnPingParameters, Resources.PingParametersTip);
			ttHelp.SetToolTip(btnAuthors, Resources.AboutTip);

			btnClose.Click += (s, e) => Close();
		}

		protected override void OnMouseDown(MouseEventArgs e)
		{
			if (e.Y < TopBorderHeight)
			{
				Capture = false;
				Message msg = WindowHelper.CreateDragMessage(Handle);
				DefWndProc(ref msg);
			}
		}

		private void SelectHelpPage(object sender, EventArgs eventArgs)
		{
			var helpButton = sender as RadioButton;
			if (helpButton != null && helpButton.Checked)
			{
				SetDoubleBuffering(false);
				carousel.SelectedIndex = helpButton.TabIndex;
			}
		}

		private void AddHelpPage(Page page)
		{
			carousel.Pages.Add(page);
		}
	}
}