﻿using System;
using System.Drawing;
using System.Reflection;
using System.Windows.Forms;

using WoTPinger.Properties;
using WoTPinger.UserInterface.Forms;

namespace WoTPinger.UserInterface
{
	public static class WindowHelper
	{
		private static readonly IntPtr Two = new IntPtr(2);
		private static bool helpIsShown;

		public static Icon GetAssemblyIcon()
		{
			return Icon.ExtractAssociatedIcon(Assembly.GetExecutingAssembly().Location);
		}

		public static Message CreateDragMessage(IntPtr handle)
		{
			return System.Windows.Forms.Message
				.Create(handle, (int)WindowMessage.NonClientButtonDown, Two, IntPtr.Zero);
		}

		public static void Help()
		{
			if (!helpIsShown)
			{
				var helpForm = new HelpForm();
				helpIsShown = true;
				helpForm.FormClosed += (sender, args) => helpIsShown = false;
				helpForm.Show();
			}
		}

		public static void Error(string errorMessage)
		{
			Message(errorMessage, MessageBoxIcon.Error);
		}

		public static void Warning(string message)
		{
			Message(message, MessageBoxIcon.Warning);
		}

		internal static void Message(string message, MessageBoxIcon icon)
		{
			MessageBox.Show(message, Resources.ApplicationName, MessageBoxButtons.OK, icon);
		}
	}
}